@@ -147,6 +147,7 @@ typedef struct
 } t_global_monitor;
 
 
+static void set_progressbar_csscolor(GtkWidget*, GdkRGBA*);
 /* ---------------------------------------------------------------------------------------------- */
 static gboolean update_monitors(t_global_monitor *global)
 {
@@ -427,6 +428,9 @@ static t_global_monitor * monitor_new(XfcePanelPlugin *plugin)
 {
     t_global_monitor *global;
     gint i;
+#if GTK_CHECK_VERSION (3, 16, 0)
+    GtkCssProvider *css_provider;
+#endif
 
     global = g_new(t_global_monitor, 1);
     global->timeout_id = 0;
@@ -496,6 +500,21 @@ static t_global_monitor * monitor_new(XfcePanelPlugin *plugin)
     for (i = 0; i < SUM; i++)
     {
         global->monitor->status[i] = GTK_WIDGET(gtk_progress_bar_new());
+#if GTK_CHECK_VERSION (3, 16, 0)
+        css_provider = gtk_css_provider_new ();
+        gtk_style_context_add_provider (
+            GTK_STYLE_CONTEXT (gtk_widget_get_style_context (GTK_WIDGET (global->monitor->status[i]))),
+            GTK_STYLE_PROVIDER (css_provider),
+            GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+        gtk_css_provider_load_from_data (css_provider, "\
+            progressbar.horizontal trough { min-height: 4px; }\
+            progressbar.horizontal progress { min-height: 4px; }\
+            progressbar.vertical trough { min-width: 4px; }\
+            progressbar.vertical progress { min-width: 4px; }",
+             -1, NULL);
+        g_object_set_data(G_OBJECT(global->monitor->status[i]), "css_provider", css_provider);
+#endif
+
         gtk_box_pack_start(GTK_BOX(global->box_bars),
                            GTK_WIDGET(global->monitor->status[i]), FALSE, FALSE, 0);
         gtk_widget_show(global->monitor->status[i]);
@@ -513,61 +532,19 @@ static t_global_monitor * monitor_new(XfcePanelPlugin *plugin)
     return global;
 }
 
-/* ---------------------------------------------------------------------------------------------- */
-static void set_label_csscolor(GtkWidget* label, GdkRGBA* color)
-{
-    GtkCssProvider *css_provider;
-    gchar * css;
-    if (color != NULL)
-    {
-#if GTK_CHECK_VERSION (3, 20, 0)
-        css = g_strdup_printf("label { color: %s; }",
-#else
-        css = g_strdup_printf(".label { color: %s; }",
-#endif
-                              gdk_rgba_to_string(color));
-    }
-    else
-    {
-#if GTK_CHECK_VERSION (3, 20, 0)
-        css = g_strdup_printf("label { color: inherit; }");
-#else
-        css = g_strdup_printf(".label { color: inherit; }");
-#endif
-    }
-    css_provider = gtk_css_provider_new ();
-    gtk_css_provider_load_from_data (css_provider, css, strlen(css), NULL);
-    g_free(css);
-
-    DBG("setting label css: %s", gtk_css_provider_to_string (css_provider));
-    gtk_style_context_add_provider (
-        GTK_STYLE_CONTEXT (gtk_widget_get_style_context (GTK_WIDGET (label))),
-        GTK_STYLE_PROVIDER (css_provider),
-        GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
-
-}
-
 /* ---------------------------------------------------------------------------------------------- */
 static void set_progressbar_csscolor(GtkWidget* pbar, GdkRGBA* color)
 {
-    GtkCssProvider *css_provider;
     gchar * css;
 #if GTK_CHECK_VERSION (3, 20, 0)
-    css = g_strdup_printf("progressbar trough { min-width: 4px; min-height: 4px; } \
-                           progressbar progress { min-width: 4px; min-height: 4px; \
-                                                  background-color: %s; background-image: none; }",
+    css = g_strdup_printf("progressbar progress { background-color: %s; background-image: none; }",
 #else
-    css = g_strdup_printf(".progressbar { background-color: %s; background-image: none; }",
+    css = g_strdup_printf(".progressbar progress { background-color: %s; background-image: none; }",
 #endif
                           gdk_rgba_to_string(color));
     DBG("setting pbar css to %s", css);
-    css_provider = gtk_css_provider_new ();
-    gtk_css_provider_load_from_data (css_provider, css, strlen(css), NULL);
+    gtk_css_provider_load_from_data (g_object_get_data(G_OBJECT(pbar),"css_provider"), css, strlen(css), NULL);
     g_free(css);
-    gtk_style_context_add_provider (
-        GTK_STYLE_CONTEXT (gtk_widget_get_style_context (GTK_WIDGET (pbar))),
-        GTK_STYLE_PROVIDER (css_provider),
-        GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 }
 
 /* ---------------------------------------------------------------------------------------------- */
@@ -602,9 +579,9 @@ static void setup_monitor(t_global_monitor *global, gboolean supress_warnings)
     if (global->monitor->options.colorize_values)
     {
 #if GTK_CHECK_VERSION (3, 16, 0)
-        set_label_csscolor(global->monitor->rcv_label,
+        xnlp_monitor_label_set_color(XNLP_MONITOR_LABEL(global->monitor->rcv_label),
                              &global->monitor->options.color[IN]);
-        set_label_csscolor(global->monitor->sent_label,
+        xnlp_monitor_label_set_color(XNLP_MONITOR_LABEL(global->monitor->sent_label),
                              &global->monitor->options.color[OUT]);
 #else
         gtk_widget_override_color(global->monitor->rcv_label, GTK_STATE_NORMAL,
@@ -617,8 +594,8 @@ static void setup_monitor(t_global_monitor *global, gboolean supress_warnings)
     {
         DBG("resetting label colors");
 #if GTK_CHECK_VERSION (3, 16, 0)
-        set_label_csscolor(global->monitor->rcv_label, NULL);
-        set_label_csscolor(global->monitor->sent_label, NULL);
+        xnlp_monitor_label_set_color(XNLP_MONITOR_LABEL(global->monitor->rcv_label), NULL);
+        xnlp_monitor_label_set_color(XNLP_MONITOR_LABEL(global->monitor->sent_label), NULL);
 #else
         gtk_widget_override_color(global->monitor->rcv_label, GTK_STATE_NORMAL, NULL);
         gtk_widget_override_color(global->monitor->sent_label, GTK_STATE_NORMAL, NULL);
@@ -807,7 +784,6 @@ static void monitor_apply_options(t_global_monitor *global)
 
     global->monitor->options.label_text =
         g_strdup(gtk_entry_get_text(GTK_ENTRY(global->monitor->opt_entry)));
-    setup_monitor(global, FALSE);
 
     if (global->monitor->options.network_device)
     {
@@ -815,7 +791,6 @@ static void monitor_apply_options(t_global_monitor *global)
     }
     global->monitor->options.network_device =
         g_strdup(gtk_entry_get_text(GTK_ENTRY(global->monitor->net_entry)));
-    setup_monitor(global, FALSE);
     
     for( i = 0; i < SUM; i++ )
     {
@@ -989,7 +964,7 @@ monitor_dialog_response (GtkWidget *dlg, int response, t_global_monitor *global)
 
 static void monitor_create_options(XfcePanelPlugin *plugin, t_global_monitor *global)
 {
-    GtkWidget        *dlg, *header;
+    GtkWidget        *dlg;
     GtkBox           *vbox, *global_vbox, *net_hbox;
     GtkWidget        *device_label, *unit_label[SUM], *max_label[SUM];
     GtkWidget        *sep1, *sep2;
